@@ -72,9 +72,9 @@ class SantaMonicaScraper(EngageScraper):
     def base_agenda_location(self, base_location):
         self._base_agenda_location = base_location
 
-    def set_committee(self, commmittee):
+    def set_committee(self, commmittee_name):
         committee = self._DBsession().query(Committee).filter(
-            Committee.name == committee).first()
+            Committee.name == committee_name).first()
         if committee is not None:
             self._Committee = committee
             self._agendas_table_location = self._Committee.agendas_table_location
